=========
Changelog
=========

0.3 (2017-10-22)
================

* Fix some issues with recode.py script.


0.2 (2017-10-22)
================

* Modernize and build with latest Cython 0.27.1.

* Include library build script for static builds.


0.1 (2013-01-19)
================

* Initial public release.
